@@ -181,8 +181,9 @@ class RobotRecord(_Record):
 
     def __init__(self, data: Optional[dict] = None):
         super().__init__(data)
-        self.source = data["source"]
-        self.immovable = data["immovable"]
+        self.source: str = data["source"]
+        self.immovable: bool = data["immovable"]
+        self.targets: dict = data["targets"]
 
 
 T = TypeVar("T", bound=_Record)
@@ -516,7 +517,7 @@ class HumanoidAnimationLibrarian(_Librarian[HumanoidAnimationRecord]):
 
     @staticmethod
     def get_library_filenames() -> List[str]:
-        return ["humanoid_animations.json"]
+        return ["humanoid_animations.json", "smpl_animations.json"]
 
     def _generate_record(self, data: dict) -> T:
         return HumanoidAnimationRecord(data)
@@ -529,7 +530,7 @@ class HumanoidLibrarian(_Librarian[HumanoidRecord]):
 
     @staticmethod
     def get_library_filenames() -> List[str]:
-        return ["humanoids.json"]
+        return ["humanoids.json", "smpl_humanoids.json"]
 
     def _generate_record(self, data: dict) -> T:
         return HumanoidRecord(data)
